@@ -14,7 +14,7 @@ from .util import DB_STATS
 from .util.request import AcceptRequest
 
 
-__version__ = '0.6.2'
+__version__ = '0.6.3'
 
 
 requests_session = requests.Session()
@@ -88,6 +88,8 @@ def create_app(config=None, **kwargs):
         return {
             'ActionType': models.ActionType,
             'PermissionType': PermissionType,
+            'app_version': __version__,
+            'site_name': app.config['SRP_SITE_NAME']
         }
     # Auto-trim whitespace
     app.jinja_env.trim_blocks = True
@@ -104,7 +106,7 @@ def sqlalchemy_before():
 
 # Auth setup
 def _copy_config_to_authmethods():
-    current_app.auth_methods = current_app.config['AUTH_METHODS']
+    current_app.auth_methods = current_app.config['SRP_AUTH_METHODS']
 
 
 # Request detail URL setup
@@ -130,11 +132,11 @@ def _copy_url_converter_config():
 # Requests session setup
 def _config_requests_session():
     try:
-        ua_string = current_app.config['USER_AGENT_STRING']
+        ua_string = current_app.config['SRP_USER_AGENT_STRING']
     except KeyError as outer_exc:
         try:
             ua_string = 'EVE-SRP/{version} ({email})'.format(
-                    email=current_app.config['USER_AGENT_EMAIL'],
+                    email=current_app.config['SRP_USER_AGENT_EMAIL'],
                     version=__version__)
         except KeyError as inner_exc:
             raise inner_exc from outer_exc
@@ -144,4 +146,4 @@ def _config_requests_session():
 
 # Killmail verification
 def _config_killmails():
-    current_app.killmail_sources = current_app.config['KILLMAIL_SOURCES']
+    current_app.killmail_sources = current_app.config['SRP_KILLMAIL_SOURCES']
