@@ -1,4 +1,6 @@
+from base64 import urlsafe_b64encode
 from itertools import groupby
+import os
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.associationproxy import association_proxy
 from sqlalchemy.ext.hybrid import hybrid_property
@@ -62,7 +64,7 @@ class Entity(db.Model, AutoID, AutoName):
     def __str__(self):
         return "{x.name}".format(x=self)
 
-    def has_permission(self, permissions, division=None):
+    def has_permission(self, permissions, division_or_request=None):
         """Returns if this entity has been granted a permission in a division.
 
         If ``division`` is ``None``, this method checks if this group has the
@@ -70,18 +72,40 @@ class Entity(db.Model, AutoID, AutoName):
 
         :param permissions: The series of permissions to check
         :type permissions: iterable
-        :param division: The division to check. May be ``None``.
-        :type division: :py:class:`Division`
+        :param division_or_request: The division to check. May be ``None`` or
+            an SRP request.
+        :type division: :py:class:`Division` or :py:class:`~.models.Request`
         :rtype bool:
         """
         if permissions in PermissionType.all:
             permissions = (permissions,)
         perms = self.permissions.filter(Permission.permission.in_(permissions))
-        if division is not None:
+        if division_or_request is not None:
+            if hasattr(division_or_request, 'division'):
+                division = division_or_request.division
+            else:
+                division = division_or_request
             perms = perms.filter_by(division=division)
         return db.session.query(perms.exists()).all()[0][0]
 
 
+class APIKey(db.Model, AutoID, AutoName, Timestamped):
+
+    user_id = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
+
+    user = db.relationship('User', back_populates='api_keys')
+
+    key = db.Column(db.LargeBinary(32), nullable=False)
+
+    def __init__(self, user):
+        self.user = user
+        self.key = os.urandom(32)
+
+    @property
+    def hex_key(self):
+        return urlsafe_b64encode(self.key).decode('utf-8').replace('=', ',')
+
+
 class User(Entity):
     """User base class.
 
@@ -114,6 +138,8 @@ class User(Entity):
     notes_made = db.relationship('Note', back_populates='noter',
             order_by='desc(Note.timestamp)', foreign_keys='Note.noter_id')
 
+    api_keys = db.relationship(APIKey, back_populates='user')
+
     @hybrid_property
     def permissions(self):
         """All :py:class:`Permission` objects associated with this user."""
