@@ -74,9 +74,8 @@ class Killmail(object):
 
         The extimated ISK loss for the ship destroyed in this killmail. This is
         an optional attribute, and is ``None`` if unsupported. If this
-        attribute is set, it should be a floating point number (or something
-        like it, like :py:class:`decimal.Decimal`) representing millions of
-        ISK.
+        attribute is set, it should be a :py:class:`~.Decimal` or a type that
+        can be used as the value for the Decimal constructor.
 
     .. py:attribute:: timestamp
 
@@ -251,13 +250,22 @@ class ZKillmail(Killmail, RequestsSessionMixin, ShipNameMixin, LocationMixin):
         self.domain = parsed.netloc
         # Check API
         api_url = [a for a in parsed]
-        api_url[2] = '/api/killID/{}'.format(self.kill_id)
+        api_url[2] = '/api/no-attackers/no-items/killID/{}'.format(
+                self.kill_id)
         resp = self.requests_session.get(urlunparse(api_url))
+        retrieval_error = LookupError("Error retrieving killmail data: {}"
+                    .format(resp.status_code))
+        if resp.status_code != 200:
+            raise retrieval_error
         try:
-            json = resp.json()[0]
+            json = resp.json()
         except ValueError as e:
-            raise LookupError("Error retrieving killmail data: {}"
-                    .format(resp.status_code)) from e
+            raise retrieval_error from e
+        try:
+            json = json[0]
+        except IndexError as e:
+            raise LookupError("Invalid killmail: {}"
+                    .format(url)) from e
         victim = json['victim']
         self.pilot_id = int(victim['characterID'])
         self.pilot = victim['characterName']
@@ -272,10 +280,9 @@ class ZKillmail(Killmail, RequestsSessionMixin, ShipNameMixin, LocationMixin):
         # for precision at large values.
         # Old versions of zKB don't give the ISK value
         try:
-            value = Decimal(json['zkb']['totalValue'])
+            self.value = Decimal(json['zkb']['totalValue'])
         except KeyError:
-            value = 0
-        self.value = value / 1000000
+            self.value = Decimal(0)
         # Parse the timestamp
         time_struct = time.strptime(json['killTime'], '%Y-%m-%d %H:%M:%S')
         self.timestamp = dt.datetime(*(time_struct[0:6]),
@@ -319,6 +326,9 @@ class CRESTMail(Killmail, RequestsSessionMixin, LocationMixin):
             self.url = urlunparse(parsed)
         # Check if it's a valid CREST URL
         resp = self.requests_session.get(self.url)
+        if resp.status_code != 200:
+            raise LookupError("Error retrieving CREST killmail: {}".format(
+                resp.json()['message']))
         try:
             json = resp.json()
         except ValueError as e:
