@@ -36,7 +36,7 @@ class AddDivisionForm(Form):
 @login_required
 @admin_permission.require()
 def add_division():
-    """Present a form for adding a view and also process that form.
+    """Present a form for adding a division and also process that form.
 
     Only accesible to adminstrators.
     """
@@ -57,6 +57,8 @@ class ChangeEntity(Form):
     action = HiddenField(validators=[AnyOf(('add', 'delete'))])
 
 
+#: List of tuples enumerating attributes that can be transformed/linked.
+#: Mainly used as the choices argument to :py:class:`~.SelectField`
 transformer_choices = [
     ('', ''),
     ('kill_timestamp', 'Kill Timestamp'),
@@ -79,6 +81,13 @@ class ChangeTransformer(Form):
 
 
 def transformer_choices(attr):
+    """Conveniece function for generating a list of transformer option tuples.
+
+    :param attr str: the name of the attribute to make a list for.
+    :return: A list of tuples suitable for the choices argument of\
+        :py:class:`StringField`
+    :rtype: list
+    """
     default_transformers = [
         ('none', 'None'),
     ]
@@ -120,16 +129,31 @@ def division_detail(division_id):
                     except MultipleResultsFound:
                         flash("Multiple entities eith the name '{}' found.".
                                 format(form.name.data), category='error')
-                permission = PermissionType.from_string(form.permission.data)
-                if form.action.data == 'add':
-                    db.session.add(Permission(division, permission, entity))
-                    flash("'{}' is now a {}.".format(entity,
-                            permission.description.lower()), "info")
-                elif form.action.data == 'delete':
-                    Permission.query.filter_by(division=division,
-                            permission=permission, entity=entity).delete()
-                    flash("'{}' is no longer a {}.".format(entity,
-                            permission.description.lower()), "info")
+                permission_type = PermissionType.from_string(
+                        form.permission.data)
+                permission_query = Permission.query.filter_by(
+                        division=division,
+                        entity=entity,
+                        permission=permission_type)
+                try:
+                    permission = permission_query.one()
+                except NoResultFound:
+                    if form.action.data == 'add':
+                        db.session.add(
+                            Permission(division, permission_type, entity))
+                        flash("'{}' is now a {}.".format(entity,
+                                permission_type.description.lower()), "info")
+                    elif form.action.data == 'delete':
+                        flash("{} is not a {}.".format(entity,
+                            permission_type.description.lower()), "warning")
+                else:
+                    if form.action.data == 'delete':
+                        permission_query.delete()
+                        flash("'{}' is no longer a {}.".format(entity,
+                                permission_type.description.lower()), "info")
+                    elif form.action.data == 'add':
+                        flash("'{}' is now a {}.".format(entity,
+                                permission_type.description.lower()), "info")
             else:
                 abort(400)
         elif request.form['form_id'] == 'transformer':
@@ -164,6 +188,12 @@ def division_detail(division_id):
 @login_required
 @admin_permission.require()
 def list_transformers(division_id, attribute=None):
+    """API method to get a list of transformers for a division.
+
+    :param division_id int: the ID of the division to look up
+    :param attribute str: a specific attribute to look up. Optional.
+    :return: JSON
+    """
     division = Division.query.get_or_404(division_id)
     if attribute is None:
         attrs = current_app.url_transformers.keys()
