@@ -2,14 +2,14 @@ from collections import OrderedDict
 import re
 
 from flask import render_template, abort, url_for, flash, Markup, request,\
-    redirect, current_app, Blueprint, Markup, json, jsonify
+    redirect, current_app, Blueprint, Markup, json, jsonify, make_response
 from flask.views import View
 from flask.ext.login import login_required, current_user
 from flask.ext.wtf import Form
 from wtforms.fields import SelectField, SubmitField, TextAreaField, HiddenField
 from wtforms.fields.html5 import URLField, DecimalField
 from wtforms.validators import InputRequired, AnyOf, URL, ValidationError,\
-        StopValidation
+    StopValidation
 
 from .. import db
 from ..models import Request, Modifier, Action, ActionType, ActionError,\
@@ -17,7 +17,8 @@ from ..models import Request, Modifier, Action, ActionType, ActionError,\
 from ..auth.permissions import SubmitRequestsPermission,\
         ReviewRequestsPermission, PayoutRequestsPermission, admin_permission
 from ..auth import PermissionType
-from ..auth.models import Division, Pilot, Permission, User, Group, Note
+from ..auth.models import Division, Pilot, Permission, User, Group, Note,\
+    APIKey
 
 
 blueprint = Blueprint('requests', __name__)
@@ -25,11 +26,15 @@ blueprint = Blueprint('requests', __name__)
 
 class RequestListing(View):
     """Abstract class for lists of :py:class:`~evesrp.models.Request`\s.
+
+    Subclasses will be able to respond to both normal HTML requests as well as
+    to API requests with JSON.
     """
 
     #: The template to use for listing requests
     template = 'list_requests.html'
 
+    #: Decorators to apply to the view functions
     decorators = [login_required]
 
     def requests(self, division_id=None):
@@ -50,8 +55,14 @@ class RequestListing(View):
 
         Part of the :py:class:`flask.views.View` interface.
         """
-        if request.wants_json or request.is_xhr:
+        if request.is_json or request.is_xhr:
             return jsonify(requests=self.requests(division_id))
+        if request.is_xml:
+            xml_list = render_template('request_list.xml',
+                    requests=self.requests(division_id))
+            response = make_response(xml_list)
+            response.headers['Content-Type'] = 'application/xml'
+            return response
         pager = self.requests(division_id).paginate(page, per_page=20)
         return render_template(self.template,
                 pager=pager, **kwargs)
@@ -71,15 +82,47 @@ class RequestListing(View):
         )
 
 
+class APIKeyForm(Form):
+    action = HiddenField(validators=[AnyOf(['add', 'delete'])])
+    key_id = HiddenField()
+
+
 class PersonalRequests(RequestListing):
-    """Shows a list of all personally submitted requests and divisions they
-    have permissions in.
+    """Shows a list of all personally submitted requests and divisions the user
+    has permissions in.
 
     It will show all requests the current user has submitted.
     """
 
     template = 'personal.html'
 
+    methods = ['GET', 'POST']
+
+    def dispatch_request(self, division_id=None, page=1, **kwargs):
+        if request.method == 'POST':
+            form = APIKeyForm()
+            if form.validate():
+                if form.action.data == 'add':
+                    key = APIKey(current_user)
+                else:
+                    key = APIKey.query.get(int(form.key_id.data))
+                    if key is not None:
+                        db.session.delete(key)
+                db.session.commit()
+        # Handle API access in here, so we can add extra data
+        if request.is_json or request.is_xhr:
+            return jsonify(
+                    requests=self.requests(division_id),
+                    api_keys=current_user.api_keys)
+        if request.is_xml:
+            xml_list = render_template('personal_list.xml',
+                    requests=self.requests(division_id))
+            response = make_response(xml_list)
+            response.headers['Content-Type'] = 'application/xml'
+            return response
+        return super(PersonalRequests, self).dispatch_request(
+                division_id, page, key_form=APIKeyForm(formdata=None))
+
     def requests(self, division_id=None):
         requests = Request.query\
                 .join(User)\
@@ -138,6 +181,7 @@ class PermissionRequestListing(RequestListing):
 
 
 class PayoutListing(PermissionRequestListing):
+    """A special view made for quickly processing payouts for requests."""
 
     template = 'payout.html'
 
@@ -147,10 +191,6 @@ class PayoutListing(PermissionRequestListing):
                 (ActionType.approved,))
 
     def dispatch_request(self, division_id=None, page=1):
-        """Returns the response to requests.
-
-        Part of the :py:class:`flask.views.View` interface.
-        """
         if not current_user.has_permission(self.permissions):
             abort(403)
         return super(PayoutListing, self).dispatch_request(
@@ -180,6 +220,9 @@ def register_perm_request_listing(app, endpoint, path, permissions, statuses):
 
 @blueprint.record
 def register_class_views(state):
+    """Called when the blueprint is registered, this function defines routes
+    for and attaches the class-based views to the app.
+    """
     try:
         prefixes = state.app.request_prefixes
     except AttributeError:
@@ -205,6 +248,9 @@ def register_class_views(state):
 
 
 class ValidKillmail(URL):
+    """Custom :py:class:'~.Field' validator that checks if any
+    :py:class:`~.Killmail` accepts the given URL.
+    """
     def __init__(self, mail_class, **kwargs):
         self.mail_class = mail_class
         super(ValidKillmail, self).__init__(**kwargs)
@@ -384,7 +430,7 @@ def get_request_details(request_id=None, srp_request=None):
         template = 'request_detail.html'
     else:
         abort(403)
-    if request.wants_json:
+    if request.is_json:
         # dump the load to encode srp_request as json and then get a dictionary
         # form of it. We need this to add a few bits of information to the
         # standard request encoding
@@ -397,6 +443,11 @@ def get_request_details(request_id=None, srp_request=None):
         enc_request['valid_actions'] = valid_actions
         enc_request['current_user'] = current_user._get_current_object()
         return jsonify(enc_request)
+    if request.is_xml:
+        xml_request = render_template('request.xml', srp_request=srp_request)
+        response = make_response(xml_request)
+        response.headers['Content-Type'] = 'application/xml'
+        return response
     return render_template(template, srp_request=srp_request,
             modifier_form=ModifierForm(formdata=None),
             payout_form=PayoutForm(formdata=None),
@@ -499,7 +550,7 @@ def _add_note(srp_request):
             check_request = db.session.query(Request.id).filter_by(id=kill_id)
             if db.session.query(check_request.exists()):
                 link = '<a href="{url}">#{kill_id}</a>'.format(
-                        url=url_for('.get_request_detail', request_id=kill_id),
+                        url=url_for('.get_request_details', request_id=kill_id),
                         kill_id=kill_id)
                 link = Markup(link)
                 note_content = note_content.replace('#' + match, link)
@@ -553,7 +604,7 @@ def request_change_division(request_id):
     division_choices = srp_request.submitter.submit_divisions()
     if len(division_choices) < 2:
         flash("No other divisions to move to.", 'info')
-        return redirect(url_for('.get_request_detail', request_id=request_id))
+        return redirect(url_for('.get_request_details', request_id=request_id))
     form = DivisionChange()
     form.division.choices = division_choices
     if form.validate_on_submit():
@@ -569,7 +620,7 @@ def request_change_division(request_id):
                 new_division.name), 'success')
         if current_user.has_permission(PermissionType.elevated, new_division) or\
                 current_user == srp_request.submitter:
-            return redirect(url_for('.get_request_detail',
+            return redirect(url_for('.get_request_details',
                 request_id=request_id))
         else:
             return redirect(url_for('.list_pending_requests'))
